@@ -99,12 +99,12 @@ sub _header_to_string {
 
 sub _path_request_to_string {
   my ($self, $info) = @_;
-  my @table = ([qw( Name In Required Description )]);
+  my @table = ([qw( Name In Type Required Description )]);
   my $str   = '';
 
   for my $p (@{$info->{parameters} || []}) {
     $p->{description} ||= NO_DESCRIPTION;
-    push @table, [@$p{qw( name in )}, $p->{required} ? 'Yes' : 'No', $p->{description}];
+    push @table, [@$p{qw( name in type )}, $p->{required} ? 'Yes' : 'No', $p->{description}];
   }
 
   $str .= sprintf "=head3 Parameters\n\n";
@@ -137,7 +137,7 @@ sub _paths_to_string {
 PATH:
   for my $path (sort keys %$paths) {
     my $url = $self->{base_url}->clone;
-    push @{$url->path->parts}, $path;
+    push @{$url->path->parts}, grep { length $_ } split '/', $path;
 
   METHOD:
     for my $method (sort keys %{$paths->{$path}}) {
@@ -151,9 +151,11 @@ PATH:
 
       next METHOD if $info->{deprecated};
       $url->query(Mojo::Parameters->new);
+      $url = $url->to_abs;
+      $url =~ s!/%7B([^%]+)%7D!/{$1}!g;
 
       $str .= sprintf "=head3 Resource URL\n\n";
-      $str .= sprintf "  %s %s\n\n", uc $method, $url->to_abs;
+      $str .= sprintf "  %s %s\n\n", uc $method, $url;
       $str .= $self->_path_request_to_string($info);
       $str .= $self->_path_response_to_string($info);
     }
@@ -238,6 +240,7 @@ sub _ascii_table {
 
   for my $row (@$rows) {
     for my $i (0 .. $#$row) {
+      $row->[$i] //= '';
       $row->[$i] =~ s/[\r\n]//g;
       my $len = length $row->[$i];
       $spec[$i] = $len if $len >= ($spec[$i] // 0);
